# Testing resources

These resources may be helpful in developing tests:  
* [Today’s plugin](https://github.com/DragaDoncila/plugin-tests) - Plugin Tests

* [pytest](https://docs.pytest.org/en/6.2.x/) - pytest is a mature full-featured Python testing tool that helps you write better programs.

* [qtbot](https://pytest-qt.readthedocs.io/en/latest/reference.html#module-pytestqt.qtbot) - `class pytestqt.qtbot.QtBot`: Instances of this class are responsible for sending events to Qt objects (usually widgets), simulating user input.
Important: Instances of this class should be accessed only by using a qtbot fixture, never instantiated directly.

* [pytest-cov](https://pytest-cov.readthedocs.io/en/latest/) - This plugin produces coverage reports. Compared to just using coverage run this plugin provides some extras.

* [codecov](https://about.codecov.io/) - As long as your code has tests and your coverage tool can output coverage results you can use Codecov.

* [GitHub workflow docs](https://docs.github.com/en/actions/quickstart) - You need only a GitHub repository to create and run a GitHub Actions workflow.  

* [Slides from workshop presentation](https://docs.google.com/presentation/d/1RFja0o6cZ8lAalAve8heuJ-Lrb4nOSUnfdpOSEhqqNo/) - These are the actual slides that were used during the testing workshop.